@@ -13,7 +13,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from __future__ import print_function
 import logging
 import os
 import pwd
@@ -36,22 +35,14 @@ class PathManager(object):
     """Helper class to manipulate ownership of a given path"""
     def __init__(self, path):
         self.path = path
-        self.uid = None
-        self.gid = None
-        self.is_dir = None
-        self.secontext = None
         self._update()
 
     def _update(self):
-        try:
-            statinfo = os.stat(self.path)
-            self.is_dir = stat.S_ISDIR(statinfo.st_mode)
-            self.uid = statinfo.st_uid
-            self.gid = statinfo.st_gid
-            self.secontext = selinux.lgetfilecon(self.path)[1]
-        except Exception:
-            LOG.exception('Could not update metadata for %s', self.path)
-            raise
+        statinfo = os.stat(self.path)
+        self.is_dir = stat.S_ISDIR(statinfo.st_mode)
+        self.uid = statinfo.st_uid
+        self.gid = statinfo.st_gid
+        self.secontext = selinux.lgetfilecon(self.path)[1]
 
     def __str__(self):
         return "uid: {} gid: {} path: {}{}".format(
@@ -87,7 +78,6 @@ class PathManager(object):
             except Exception:
                 LOG.exception('Could not change ownership of %s: ',
                               self.path)
-                raise
         else:
             LOG.info('Ownership of %s already %d:%d',
                      self.path,
@@ -111,7 +101,7 @@ class PathManager(object):
                 else:
                     raise
         except Exception:
-            LOG.exception('Could not set selinux context of %s to %s:',
+            LOG.error('Could not set selinux context of %s to %s:',
                           self.path, context)
             raise
 
@@ -138,8 +128,7 @@ class NovaStatedirOwnershipManager(object):
        docker nova uid/gid is not known in this context).
     """
     def __init__(self, statedir, upgrade_marker='upgrade_marker',
-                 nova_user='nova', secontext_marker='../_nova_secontext',
-                 exclude_paths=None):
+                 nova_user='nova', secontext_marker='../_nova_secontext'):
         self.statedir = statedir
         self.nova_user = nova_user
 
@@ -147,13 +136,6 @@ class NovaStatedirOwnershipManager(object):
         self.secontext_marker_path = os.path.normpath(os.path.join(statedir, secontext_marker))
         self.upgrade = os.path.exists(self.upgrade_marker_path)
 
-        self.exclude_paths = [self.upgrade_marker_path]
-        if exclude_paths is not None:
-            for p in exclude_paths:
-                if not p.startswith(os.path.sep):
-                    p = os.path.join(self.statedir, p)
-                self.exclude_paths.append(p)
-
         self.target_uid, self.target_gid = self._get_nova_ids()
         self.previous_uid, self.previous_gid = self._get_previous_nova_ids()
         self.id_change = (self.target_uid, self.target_gid) != \
@@ -181,36 +163,29 @@ class NovaStatedirOwnershipManager(object):
         for f in os.listdir(top):
             pathname = os.path.join(top, f)
 
-            if pathname in self.exclude_paths:
+            if pathname == self.upgrade_marker_path:
                 continue
 
-            try:
-                pathinfo = PathManager(pathname)
-                LOG.info("Checking %s", pathinfo)
-                if pathinfo.is_dir:
-                    # Always chown the directories
-                    pathinfo.chown(self.target_uid, self.target_gid)
-                    chcon_r = chcon
-                    if chcon:
-                        chcon_r = pathinfo.chcon(self.target_secontext)
-                    self._walk(pathname, chcon_r)
-                elif self.id_change:
-                    # Only chown files if it's an upgrade and the file is owned by
-                    # the host nova uid/gid
-                    pathinfo.chown(
-                        self.target_uid if pathinfo.uid == self.previous_uid
-                        else pathinfo.uid,
-                        self.target_gid if pathinfo.gid == self.previous_gid
-                        else pathinfo.gid
-                    )
-                    if chcon:
-                        pathinfo.chcon(self.target_secontext)
-            except Exception:
-                # Likely to have been caused by external systems
-                # interacting with this directory tree,
-                # especially on NFS e.g snapshot dirs.
-                # Just ignore it and continue on to the next entry
-                continue
+            pathinfo = PathManager(pathname)
+            LOG.info("Checking %s", pathinfo)
+            if pathinfo.is_dir:
+                # Always chown the directories
+                pathinfo.chown(self.target_uid, self.target_gid)
+                chcon_r = chcon
+                if chcon:
+                    chcon_r = pathinfo.chcon(self.target_secontext)
+                self._walk(pathname, chcon_r)
+            elif self.id_change:
+                # Only chown files if it's an upgrade and the file is owned by
+                # the host nova uid/gid
+                pathinfo.chown(
+                    self.target_uid if pathinfo.uid == self.previous_uid
+                    else pathinfo.uid,
+                    self.target_gid if pathinfo.gid == self.previous_gid
+                    else pathinfo.gid
+                )
+                if chcon:
+                    pathinfo.chcon(self.target_secontext)
 
     def run(self):
         LOG.info('Applying nova statedir ownership')
@@ -237,12 +212,5 @@ class NovaStatedirOwnershipManager(object):
         LOG.info('Nova statedir ownership complete')
 
 
-def get_exclude_paths():
-    exclude_paths = os.environ.get('NOVA_STATEDIR_OWNERSHIP_SKIP')
-    if exclude_paths is not None:
-        exclude_paths = exclude_paths.split(os.pathsep)
-    return exclude_paths
-
-
 if __name__ == '__main__':
-    NovaStatedirOwnershipManager('/var/lib/nova', exclude_paths=get_exclude_paths()).run()
+    NovaStatedirOwnershipManager('/var/lib/nova').run()
