@@ -13,10 +13,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from unittest import mock
+
 import contextlib
-import mock
-import os
-from os import stat as orig_stat
 import six
 import stat
 import sys
@@ -34,7 +33,6 @@ class FakeSelinux(object):
         pass
 sys.modules["selinux"] = FakeSelinux
 
-from container_config_scripts.nova_statedir_ownership import get_exclude_paths  # noqa: E402
 from container_config_scripts.nova_statedir_ownership import \
     NovaStatedirOwnershipManager  # noqa: E402
 from container_config_scripts.nova_statedir_ownership import PathManager  # noqa: E402
@@ -77,39 +75,6 @@ def generate_testtree1(nova_uid, nova_gid):
                          st_gid=nova_gid),
             'nfs': False,
         },
-        '/var/lib/nova/instances/removeddir': {
-            'stat': FakeStatInfo(st_mode=stat.S_IFDIR,
-                                 st_uid=nova_uid,
-                                 st_gid=nova_gid),
-            'nfs': False,
-            'removed_when': 'listdir'
-        },
-        '/var/lib/nova/instances/removedfile': {
-            'stat': FakeStatInfo(st_mode=stat.S_IFREG,
-                                 st_uid=0,
-                                 st_gid=nova_gid),
-            'nfs': False,
-            'removed_when': 'lgetfilecon'
-        },
-        '/var/lib/nova/instances/removedfile2': {
-            'stat': FakeStatInfo(st_mode=stat.S_IFREG,
-                                 st_uid=0,
-                                 st_gid=nova_gid),
-            'nfs': False,
-            'removed_when': 'lsetfilecon'
-        },
-        '/var/lib/nova/instances/removedfile3': {
-            'nfs': False,
-            'removed_when': 'stat'
-        },
-
-        '/var/lib/nova/instances/removeddir2': {
-            'stat': FakeStatInfo(st_mode=stat.S_IFDIR,
-                                 st_uid=nova_uid,
-                                 st_gid=nova_gid),
-            'nfs': False,
-            'removed_when': 'lsetfilecon'
-        },
         '/var/lib/nova/instances/foo': {
             'stat': FakeStatInfo(st_mode=stat.S_IFDIR,
                                  st_uid=nova_uid,
@@ -128,20 +93,6 @@ def generate_testtree1(nova_uid, nova_gid):
                                  st_gid=nova_gid),
             'nfs': True,
         },
-        '/var/lib/nova/instances/foo/removeddir': {
-            'stat': FakeStatInfo(st_mode=stat.S_IFDIR,
-                                 st_uid=nova_uid,
-                                 st_gid=nova_gid),
-            'nfs': True,
-            'removed_when': 'listdir'
-        },
-        '/var/lib/nova/instances/foo/removeddir2': {
-            'stat': FakeStatInfo(st_mode=stat.S_IFDIR,
-                                 st_uid=0,
-                                 st_gid=nova_gid),
-            'nfs': True,
-            'removed_when': 'chown'
-        },
         '/var/lib/nova/instances/foo/abc': {
             'stat': FakeStatInfo(st_mode=stat.S_IFREG,
                                  st_uid=0,
@@ -170,25 +121,14 @@ def generate_testtree2(marker_uid, marker_gid, *args, **kwargs):
     return tree
 
 
-def check_removed(path, op, testtree):
-    if op == testtree.get(path, {}).get('removed_when', ''):
-        raise OSError(2, 'No such file or directory: ' + path)
-
-
 def generate_fake_stat(testtree):
     def fake_stat(path):
-        check_removed(path, 'stat', testtree)
-        if path.startswith('/var'):
-            return testtree.get(path, {}).get('stat')
-        else:
-            # Tracebacks need to use the real stat
-            return orig_stat(path)
+        return testtree.get(path, {}).get('stat')
     return fake_stat
 
 
 def generate_fake_chown(testtree):
     def fake_chown(path, uid, gid):
-        check_removed(path, 'chown', testtree)
         if uid != -1:
             testtree[path]['stat'].st_uid = uid
         if gid != -1:
@@ -198,14 +138,12 @@ def generate_fake_chown(testtree):
 
 def generate_fake_exists(testtree):
     def fake_exists(path):
-        check_removed(path, 'exists', testtree)
         return path in testtree
     return fake_exists
 
 
 def generate_fake_listdir(testtree):
     def fake_listdir(path):
-        check_removed(path, 'listdir', testtree)
         path_parts = path.split('/')
         for entry in testtree:
             entry_parts = entry.split('/')
@@ -217,21 +155,16 @@ def generate_fake_listdir(testtree):
 
 def generate_fake_unlink(testtree):
     def fake_unlink(path):
-        check_removed(path, 'unlink', testtree)
         del testtree[path]
     return fake_unlink
 
 
-def generate_fake_lgetfilecon(testtree):
-    def fake_lgetfilecon(path):
-        check_removed(path, 'lgetfilecon', testtree)
-
-
 def generate_fake_lsetfilecon(testtree):
     def fake_lsetfilecon(path, context):
-        check_removed(path, 'lsetfilecon', testtree)
         if testtree[path]['nfs']:
-            raise OSError(95, 'Operation not supported')
+            e = OSError('Operation not supported')
+            e.errno = 95
+            raise e
 
 
 @contextlib.contextmanager
@@ -242,7 +175,6 @@ def fake_testtree(testtree):
     fake_listdir = generate_fake_listdir(testtree)
     fake_unlink = generate_fake_unlink(testtree)
     fake_lsetfilecon = generate_fake_lsetfilecon(testtree)
-    fake_lgetfilecon = generate_fake_lgetfilecon(testtree)
     with mock.patch('os.chown',
                     side_effect=fake_chown) as fake_chown:
         with mock.patch('os.path.exists',
@@ -259,8 +191,7 @@ def fake_testtree(testtree):
                                 ) as fake_unlink:
                             with mock.patch(
                                     'selinux.lgetfilecon',
-                                    side_effect=fake_lgetfilecon,
-                                    return_value=[10, 'newcontext']
+                                    return_value=[10, 'newcontext'],
                                     ) as fake_lgetfilecon:
                                 with mock.patch(
                                         'selinux.lsetfilecon',
@@ -345,7 +276,7 @@ class NovaStatedirOwnershipManagerTestCase(base.BaseTestCase):
 
         with fake_testtree(testtree) as (fake_chown, _, _, _, _, _, fake_lsetfilecon):
             NovaStatedirOwnershipManager('/var/lib/nova').run()
-            fake_chown.assert_called_once_with('/var/lib/nova/instances/foo/removeddir2', 100, -1)
+            fake_chown.assert_not_called()
             fake_lsetfilecon.assert_any_call('/var/lib/nova', 'newcontext')
             fake_lsetfilecon.assert_any_call('/var/lib/nova/instances/foo', 'newcontext')
             chcon_paths = [x[0][0] for x in fake_lsetfilecon.call_args_list]
@@ -359,7 +290,7 @@ class NovaStatedirOwnershipManagerTestCase(base.BaseTestCase):
 
         with fake_testtree(testtree) as (fake_chown, _, _, _, fake_unlink, _, _):
             NovaStatedirOwnershipManager('/var/lib/nova').run()
-            fake_chown.assert_called_once_with('/var/lib/nova/instances/foo/removeddir2', 100, -1)
+            fake_chown.assert_not_called()
             fake_unlink.assert_called_with('/var/lib/nova/upgrade_marker')
 
     def test_upgrade_marker_id_change(self):
@@ -379,9 +310,6 @@ class NovaStatedirOwnershipManagerTestCase(base.BaseTestCase):
             if k == '/var/lib/_nova_secontext':
                 # Ignore, outside tree
                 continue
-            if testtree[k].get('removed_when', False):
-                # Ignore, deleted
-                continue
             v = v['stat']
             if v.st_uid == other_uid or v.st_gid == other_gid:
                 expected_changes[k] = (
@@ -394,31 +322,3 @@ class NovaStatedirOwnershipManagerTestCase(base.BaseTestCase):
             for fn, expected in six.iteritems(expected_changes):
                 assert_ids(testtree, fn, expected[0], expected[1])
             fake_unlink.assert_called_with('/var/lib/nova/upgrade_marker')
-
-    def test_exclude_path(self):
-        testtree = generate_testtree1(current_uid, current_gid)
-
-        with fake_testtree(testtree) as (
-                fake_chown, _, fake_listdir, fake_stat, _, _, _):
-            manager = NovaStatedirOwnershipManager(
-                '/var/lib/nova',
-                exclude_paths=['instances/foo/bar', '/var/lib/nova/instances/foo/removeddir']
-            )
-            manager.run()
-            self.assertIn('/var/lib/nova/instances/foo/bar', manager.exclude_paths)
-            self.assertIn('/var/lib/nova/instances/foo/removeddir', manager.exclude_paths)
-            self.assertNotIn(mock.call('/var/lib/nova/instances/foo/bar'), fake_stat.call_args_list)
-            self.assertNotIn(mock.call('/var/lib/nova/instances/foo/bar'), fake_chown.call_args_list)
-            self.assertNotIn(mock.call('/var/lib/nova/instances/foo/removeddir'), fake_stat.call_args_list)
-            self.assertNotIn(mock.call('/var/lib/nova/instances/foo/removeddir'), fake_chown.call_args_list)
-            self.assertNotIn(mock.call('/var/lib/nova/instances/foo/removeddir'), fake_listdir.call_args_list)
-
-    @mock.patch.dict(os.environ, {'NOVA_STATEDIR_OWNERSHIP_SKIP': 'foo:bar:foo/bar/baz'})
-    def test_get_exclude_paths(self):
-        expected = [
-            'foo',
-            'bar',
-            'foo/bar/baz'
-        ]
-        exclude_paths = get_exclude_paths()
-        self.assertEqual(exclude_paths, expected)
