@@ -57,6 +57,8 @@ REQUIRED_DOCKER_SECTIONS = ['service_name', 'docker_config', 'puppet_config',
 OPTIONAL_DOCKER_SECTIONS = ['container_puppet_tasks', 'upgrade_tasks',
                             'deploy_steps_tasks',
                             'pre_upgrade_rolling_tasks',
+                            'fast_forward_upgrade_tasks',
+                            'fast_forward_post_upgrade_tasks',
                             'post_upgrade_tasks', 'update_tasks',
                             'post_update_tasks', 'service_config_settings',
                             'host_prep_tasks', 'metadata_settings',
@@ -100,6 +102,8 @@ REQUIRED_DOCKER_SECTIONS_OVERRIDES = {
 }
 # ansible tasks cannot be an empty dict or ansible is unhappy
 ANSIBLE_TASKS_SECTIONS = ['upgrade_tasks', 'pre_upgrade_rolling_tasks',
+                          'fast_forward_upgrade_tasks',
+                          'fast_forward_post_upgrade_tasks',
                           'post_upgrade_tasks', 'update_tasks',
                           'post_update_tasks', 'host_prep_tasks',
                           'external_deploy_tasks',
@@ -259,10 +263,6 @@ VALIDATE_DOCKER_OVERRIDE = {
   # Does not follow the filename pattern
   './deployment/multipathd/multipathd-container.yaml': True
 }
-VALIDATE_DOCKER_PUPPET_CONFIG_OVERRIDE = {
-    # inherits from nova-conductor
-  './deployment/nova/nova-manager-container-puppet.yaml': False,
-}
 DEPLOYMENT_RESOURCE_TYPES = [
     'OS::Heat::SoftwareDeploymentGroup',
     'OS::Heat::StructuredDeploymentGroup',
@@ -344,7 +344,7 @@ def validate_endpoint_map(base_map, env_map):
 
 def validate_role_name(filename):
     with open(filename, 'r') as f:
-        tpl = yaml.safe_load(f.read())
+        tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     role_data = tpl[0]
     if role_data['name'] != os.path.basename(filename).split('.')[0]:
@@ -360,7 +360,7 @@ def validate_hci_compute_services_default(env_filename, env_tpl):
     roles_filename = os.path.join(os.path.dirname(env_filename),
                                   '../roles/Compute.yaml')
     with open(roles_filename, 'r') as f:
-        roles_tpl = yaml.safe_load(f.read())
+        roles_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     for role in roles_tpl:
         if role['name'] == 'Compute':
@@ -376,7 +376,7 @@ def validate_hci_computehci_role(hci_role_filename, hci_role_tpl):
     compute_role_filename = os.path.join(os.path.dirname(hci_role_filename),
                                          './Compute.yaml')
     with open(compute_role_filename, 'r') as f:
-        compute_role_tpl = yaml.safe_load(f.read())
+        compute_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     compute_role_services = compute_role_tpl[0]['ServicesDefault']
     for role in hci_role_tpl:
@@ -394,7 +394,7 @@ def validate_controller_dashboard(filename, tpl):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.safe_load(f.read())
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
@@ -411,7 +411,7 @@ def validate_controller_storage_nfs(filename, tpl, exclude_service=()):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.safe_load(f.read())
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
@@ -430,7 +430,7 @@ def validate_hci_role(hci_role_filename, hci_role_tpl):
         compute_role_filename = \
             os.path.join(os.path.dirname(hci_role_filename), './Compute.yaml')
         with open(compute_role_filename, 'r') as f:
-            compute_role_tpl = yaml.safe_load(f.read())
+            compute_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         compute_role_services = compute_role_tpl[0]['ServicesDefault']
         for role in hci_role_tpl:
@@ -469,7 +469,7 @@ def validate_ceph_role(ceph_role_filename, ceph_role_tpl):
         ceph_storage_role_filename = \
             os.path.join(os.path.dirname(ceph_role_filename), './CephStorage.yaml')
         with open(ceph_storage_role_filename, 'r') as f:
-            ceph_storage_role_tpl = yaml.safe_load(f.read())
+            ceph_storage_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         ceph_storage_role_services = ceph_storage_role_tpl[0]['ServicesDefault']
         for role in ceph_role_tpl:
@@ -500,7 +500,7 @@ def validate_controller_no_ceph_role(filename, tpl):
     control_role_filename = os.path.join(os.path.dirname(filename),
                                          './Controller.yaml')
     with open(control_role_filename, 'r') as f:
-        control_role_tpl = yaml.safe_load(f.read())
+        control_role_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     control_role_services = control_role_tpl[0]['ServicesDefault']
     for role in tpl:
@@ -524,7 +524,7 @@ def validate_with_compute_role_services(role_filename, role_tpl, exclude_service
     cmpt_filename = os.path.join(os.path.dirname(role_filename),
                                  './Compute.yaml')
     with open(cmpt_filename, 'r') as f:
-        cmpt_tpl = yaml.safe_load(f.read())
+        cmpt_tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
     cmpt_services = cmpt_tpl[0]['ServicesDefault']
     cmpt_services = [x for x in cmpt_services if (x not in exclude_service)]
@@ -663,7 +663,7 @@ def validate_docker_service_mysql_usage(filename, tpl):
                     os.path.exists(newfilename.replace('.yaml', '.j2.yaml')):
                     return  # Skip for now if it's templated
                 with open(newfilename, 'r') as newfile:
-                    newtmp = yaml.safe_load(newfile.read())
+                    newtmp = yaml.load(newfile.read(), Loader=yaml.SafeLoader)
                 read_all(newfilename, newtmp)
 
     read_all(filename, tpl)
@@ -743,8 +743,7 @@ def validate_docker_service(filename, tpl):
                           % (section_name, filename))
                     return 1
 
-        if 'puppet_config' in role_data and \
-                VALIDATE_DOCKER_PUPPET_CONFIG_OVERRIDE.get(filename, True):
+        if 'puppet_config' in role_data:
             if validate_docker_service_mysql_usage(filename, tpl):
                 print('ERROR: could not validate use of mysql service for %s.'
                       % filename)
@@ -804,6 +803,16 @@ def validate_docker_service(filename, tpl):
                 print('ERROR: upgrade_tasks validation failed')
                 return 1
 
+        if 'fast_forward_upgrade_tasks' in role_data and role_data['fast_forward_upgrade_tasks']:
+            if validate_upgrade_tasks(role_data['fast_forward_upgrade_tasks']):
+                print('ERROR: fast_forward_upgrade_tasks validation failed')
+                return 1
+
+        if 'fast_forward_post_upgrade_tasks' in role_data and role_data['fast_forward_post_upgrade_tasks']:
+            if validate_upgrade_tasks(role_data['fast_forward_post_upgrade_tasks']):
+                print('ERROR: fast_forward_post_upgrade_tasks validation failed')
+                return 1
+
     if 'parameters' in tpl:
         for param in required_params:
             if param not in tpl['parameters']:
@@ -861,6 +870,16 @@ def validate_service(filename, tpl):
                 print('ERROR: upgrade_tasks validation failed')
                 return 1
 
+        if 'fast_forward_upgrade_tasks' in role_data and role_data['fast_forward_upgrade_tasks']:
+            if validate_upgrade_tasks(role_data['fast_forward_upgrade_tasks']):
+                print('ERROR: fast_forward_upgrade_tasks validation failed')
+                return 1
+
+        if 'fast_forward_post_upgrade_tasks' in role_data and role_data['fast_forward_post_upgrade_tasks']:
+            if validate_upgrade_tasks(role_data['fast_forward_post_upgrade_tasks']):
+                print('ERROR: fast_forward_post_upgrade_tasks validation failed')
+                return 1
+
     if 'parameters' in tpl:
         for param in required_params:
             if param not in tpl['parameters']:
@@ -1010,16 +1029,12 @@ def validate_service_hiera_interpol(f, tpl):
             if enter_lists and path[-1] != 0 and path[-2] != 'get_param':
                 continue
 
-            # Omit if it is not a hiera config setting
-            if path[1] in ['kolla_config']:
-                continue
-
             path_str = ';'.join(str(x) for x in path)
             # NOTE(bogdando): Omit foo_network keys looking like a network
             # name. The only exception is allow anything under
             # str_replace['params'] ('str_replace;params' in the str notation).
             # We need to escape because of '$' char may be in templated params.
-            query = re.compile(r'\\;str(\\)?_replace\\;params\\;\S*?net',
+            query = re.compile(r'(\\)?;str(\\)?_replace(\\)?;params(\\)?;\S*?net',
                                re.IGNORECASE)
             if not query.search(re.escape(path_str)):
                 # Keep parsing, if foo_vip_network, or anything
@@ -1031,7 +1046,7 @@ def validate_service_hiera_interpol(f, tpl):
 
             # Omit mappings in tht, like:
             # [NetXxxMap, <... ,> {get_param: [ServiceNetMap, ...
-            if re.search(r'Map.*get\\_param', re.escape(path_str)):
+            if re.search(r'Map.*get(\\)?_param', re.escape(path_str)):
                 continue
 
             # For the remaining cases, verify if there is a template
@@ -1121,7 +1136,7 @@ def validate(filename, param_map):
     retval = 0
     try:
         with open(filename, 'r') as f:
-            tpl = yaml.safe_load(f.read())
+            tpl = yaml.load(f.read(), Loader=yaml.SafeLoader)
 
         is_heat_template = 'heat_template_version' in tpl
 
@@ -1314,11 +1329,11 @@ def validate_upgrade_tasks(upgrade_tasks):
 def validate_network_data_file(data_file_path):
     try:
         with open(data_file_path, 'r') as data_file:
-            data_file = yaml.safe_load(data_file.read())
+            data_file = yaml.load(data_file.read(), Loader=yaml.SafeLoader)
 
         base_file_path = os.path.dirname(data_file_path) + "/network_data.yaml"
         with open(base_file_path, 'r') as base_file:
-            base_file = yaml.safe_load(base_file.read())
+            base_file = yaml.load(base_file.read(), Loader=yaml.SafeLoader)
 
         retval = 0
         for n in base_file:
